==> opensarlab_lib-0.0.3.tar.gz: opensarlab_lib-0.0.3/README.md <==
# opensarlab-lib

[![PyPI license](https://img.shields.io/pypi/l/opensarlab_lib.svg)](https://pypi.python.org/pypi/opensarlab-lib/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/opensarlab_lib.svg)](https://pypi.python.org/pypi/opensarlab-lib/)
[![PyPI version](https://img.shields.io/pypi/v/opensarlab_lib.svg)](https://pypi.python.org/pypi/opensarlab-lib/)

[comment]: <> ([![Conda version]&#40;https://img.shields.io/conda/vn/conda-forge/opensarlab_lib&#41;]&#40;https://anaconda.org/conda-forge/opensarlab_lib&#41;)

[comment]: <> ([![Conda platforms]&#40;https://img.shields.io/conda/pn/conda-forge/opensarlab_lib&#41;]&#40;https://anaconda.org/conda-forge/opensarlab_lib&#41;)

A python library to support [ASF OpenSARlab's Jupyter Notebook repository](https://github.com/ASFOpenSARlab/opensarlab-notebooks)

## Install

In order to easily manage dependencies, we recommend using dedicated project environments with
[Anaconda/Miniconda](https://docs.conda.io/projects/conda/en/latest/user-guide/install/index.html). or
[Python virtual environments](https://docs.python.org/3/tutorial/venv.html). 

The opensarlab_lib can be installed with 

[comment]: <> (into a conda environment with)

[comment]: <> (```)

[comment]: <> (conda install -c conda-forge opensarlab_lib)

[comment]: <> (```)

[comment]: <> (or into a virtual environment with)

```
python -m pip install opensarlab-lib
```

## Contact Us

Found a bug? Want to request a feature?
[open an issue](https://github.com/ASFOpenSARlab/opensarlab-lib/issues/new)

==> opensarlab_lib-0.0.13.tar.gz: opensarlab_lib-0.0.13/README.md <==
# The future home of opensarlab-lib

[![PyPI license](https://img.shields.io/pypi/l/opensarlab_lib.svg)](https://pypi.python.org/pypi/opensarlab_lib/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/opensarlab_lib.svg)](https://pypi.python.org/pypi/opensarlab_lib/)
[![PyPI version](https://img.shields.io/pypi/v/opensarlab_lib.svg)](https://pypi.python.org/pypi/opensarlab_lib/)

[comment]: <> ([![Conda version]&#40;https://img.shields.io/conda/vn/conda-forge/opensarlab_lib&#41;]&#40;https://anaconda.org/conda-forge/opensarlab_lib&#41;)

[comment]: <> ([![Conda platforms]&#40;https://img.shields.io/conda/pn/conda-forge/opensarlab_lib&#41;]&#40;https://anaconda.org/conda-forge/opensarlab_lib&#41;)

A python library to support [ASF OpenSARlab's Jupyter Notebook repository](https://github.com/ASFOpenSARlab/opensarlab-notebooks)

## Install

In order to easily manage dependencies, we recommend using dedicated project environments with
[Anaconda/Miniconda](https://docs.conda.io/projects/conda/en/latest/user-guide/install/index.html). or
[Python virtual environments](https://docs.python.org/3/tutorial/venv.html). 

The opensarlab_lib can be installed with 

[comment]: <> (into a conda environment with)

[comment]: <> (```)

[comment]: <> (conda install -c conda-forge opensarlab_lib)

[comment]: <> (```)

[comment]: <> (or into a virtual environment with)

```
python -m pip install opensarlab_lib
```

## Contact Us

Found a bug? Want to request a feature?
[open an issue](https://github.com/ASFOpenSARlab/opensarlab-lib/issues/new)
